==> module-browser-0.0.56-32.tgz: package/src/module.tsx <==
import * as React from 'react';
import { Feature } from '@common-stack/client-react';
import { Files, /** Editors */ } from '@files-stack/client-react';
import { reducers, setRootPath, filesModule } from '@files-stack/client-state';
import {
    filesResolvers, defaults, editorResolvers, filesTreeResolvers, filesSchema, dataIdFromObject,
    modelContentChangeEpic, modelSaveEpic, editorSchema, filesTreeSchema, fragmentMatcher,
    untitledEditorSchema,
} from '@files-stack/client-state';
import { merge } from 'lodash';
import { IClientFileService, ClientTypes, IFilesTreeService, IUntitledEditorService,
     IClientService, IClientTextFileService,
     } from '@files-stack/core';
import { interfaces } from 'inversify';

const actionFunctions = [setRootPath];

const filesServiceGen = (container: interfaces.Container): IClientService => {
    return {
        fileService: container.get<IClientFileService>(ClientTypes.IFileService),
        textFileService: container.get<IClientTextFileService>(ClientTypes.ITextFileService),
        filesTreeService: container.get<IFilesTreeService>(ClientTypes.IFilesTreeService),
        untitledEditorService: container.get<IUntitledEditorService>(ClientTypes.IUntitledEditorService),
    };
};

export default new Feature({
    leftMainPanelItems: { files: <Files /> },
    middleMainPanelItems: { editors: <div>ToDO</div>  }, // <Editor/>
    middleMainPanelItemsProps: { editors: { actionFunctions } },
    reducer: { ...reducers },
    createContainerFunc: filesModule,
    clientStateParams: [{ resolvers: merge(filesResolvers, editorResolvers, filesTreeResolvers), defaults, 
        typeDefs: [filesSchema, untitledEditorSchema, editorSchema, filesTreeSchema], fragmentMatcher: fragmentMatcher as any }],
    dataIdFromObject,
    createServiceFunc: filesServiceGen,
    epic: [modelContentChangeEpic, modelSaveEpic],
});

==> module-browser-0.0.56-35.tgz: package/src/module.tsx <==
import * as React from 'react';
import { Feature } from '@common-stack/client-react';
import { Files, EditorComponent,  /** Editors */ } from '@files-stack/client-react';
import { reducers, setRootPath, filesModule } from '@files-stack/client-state';
import {
    filesResolvers, defaults, editorResolvers, filesTreeResolvers, filesSchema, dataIdFromObject,
    modelContentChangeEpic, modelSaveEpic, editorSchema, filesTreeSchema, fragmentMatcher,
    untitledEditorSchema,
} from '@files-stack/client-state';
import { merge } from 'lodash';
import { IClientFileService, ClientTypes, IFilesTreeService, IUntitledEditorService,
     IClientService, IClientTextFileService, ITextFileEditorModel,
     } from '@files-stack/core';
     import { DockLayout } from '@ide-layout/client-react';
     import { interfaces } from 'inversify';

const actionFunctions = [setRootPath];

const filesServiceGen = (container: interfaces.Container): IClientService => {
    return {
        fileService: container.get<IClientFileService>(ClientTypes.IFileService),
        textFileService: container.get<IClientTextFileService>(ClientTypes.ITextFileService),
        filesTreeService: container.get<IFilesTreeService>(ClientTypes.IFilesTreeService),
        untitledEditorService: container.get<IUntitledEditorService>(ClientTypes.IUntitledEditorService),
        textFileEditorModel: container.get<ITextFileEditorModel>(ClientTypes.ITextFileEditorModel),
    };
};

const Editor = ({ input }) => React.useMemo(() => EditorComponent({ input }), [input]);
export default new Feature({
    leftMainPanelItems: { files: <Files /> },
    middleMainPanelItems: { editors: <DockLayout contentComponent={EditorComponent} /> }, // <Editor/>
    middleMainPanelItemsProps: { editors: { actionFunctions } },
    reducer: { ...reducers },
    createContainerFunc: filesModule,
    clientStateParams: [{ resolvers: merge(filesResolvers, editorResolvers, filesTreeResolvers), defaults, 
        typeDefs: [filesSchema, untitledEditorSchema, editorSchema, filesTreeSchema], fragmentMatcher: fragmentMatcher as any }],
    dataIdFromObject,
    createServiceFunc: filesServiceGen,
    epic: [modelContentChangeEpic, modelSaveEpic],
});
